// @flow
var C = /*#__PURE__*/function () {
  "use strict";

  function C() {}

  var _proto = C.prototype;

  _proto.m = function m(x: number): string {
    return 'a';
  };

  return C;
}();
